@@ -1,6 +1,6 @@
 package RPC::Serialized::Handler::YATG::Retrieve;
 {
-  $RPC::Serialized::Handler::YATG::Retrieve::VERSION = '4.112532';
+  $RPC::Serialized::Handler::YATG::Retrieve::VERSION = '5.130510_001';
 }
 
 use strict;
@@ -18,8 +18,8 @@ sub invoke {
 
 # ABSTRACT: RPC handler for YATG::Retrieve::Disk
 
-
 __END__
+
 =pod
 
 =head1 NAME
@@ -28,7 +28,7 @@ RPC::Serialized::Handler::YATG::Retrieve - RPC handler for YATG::Retrieve::Disk
 
 =head1 VERSION
 
-version 4.112532
+version 5.130510_001
 
 =head1 DESCRIPTION
 
@@ -36,6 +36,34 @@ This module implements an L<RPC::Serialized> handler for
 L<YATG::Retrieve::Disk>.  There is no special configuration, and all received
 parameters are passed on to C<YATG::Retrieve::Disk::retrieve()> verbatim.
 
+=head1 REQUIREMENTS
+
+Install the following additional modules to use this plugin:
+
+=over 4
+
+=item *
+
+L<RPC::Serialized>
+
+=item *
+
+L<Tile::File::FixedRecLen>
+
+=item *
+
+L<integer>
+
+=item *
+
+L<Time::Local>
+
+=item *
+
+L<Fcntl>
+
+=back
+
 =head1 INSTALLATION
 
 You'll need to run an RPC::Serialized server, of course, and configure it
@@ -72,10 +100,9 @@ Oliver Gorwits <oliver@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by University of Oxford.
+This software is copyright (c) 2013 by University of Oxford.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
