@@ -1,6 +1,6 @@
 package YATG::Store::Memcached;
 {
-  $YATG::Store::Memcached::VERSION = '4.112532';
+  $YATG::Store::Memcached::VERSION = '5.130510_001';
 }
 
 use strict;
@@ -61,8 +61,8 @@ sub store {
 
 # ABSTRACT: Back-end module to store polled data to a Memcached
 
-
 __END__
+
 =pod
 
 =head1 NAME
@@ -71,7 +71,7 @@ YATG::Store::Memcached - Back-end module to store polled data to a Memcached
 
 =head1 VERSION
 
-version 4.112532
+version 5.130510_001
 
 =head1 DESCRIPTION
 
@@ -115,6 +115,18 @@ data stored in the memcache using the two lookup tables and then retrieving
 the desired keys. There is an example of this in the C<examples/> folder of
 this distribution, called C<check_interfaces>. It is a Nagios2 check script.
 
+=head1 REQUIREMENTS
+
+Install the following additonal module to use this plugin:
+
+=over 4
+
+=item *
+
+L<Cache::Memcached>
+
+=back
+
 =head1 CONFIGURATION
 
 In the main C<yatg_updater> configuration, you must provide details of the
@@ -139,10 +151,9 @@ Oliver Gorwits <oliver@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by University of Oxford.
+This software is copyright (c) 2013 by University of Oxford.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
