@@ -1,19 +1,19 @@
 package YATG::Store::STDOUT;
 {
-  $YATG::Store::STDOUT::VERSION = '4.112532';
+  $YATG::Store::STDOUT::VERSION = '5.130510_001';
 }
 
 use strict;
 use warnings FATAL => 'all';
 
-use Data::Dumper;
+use Data::Printer;
 
 sub store {
     my ($config, $stamp, $results) = @_;
 
     print "YATG run at ". scalar localtime() .":\n"
         if $ENV{YATG_DEBUG} || $config->{yatg}->{debug};
-    print Dumper $results;
+    p $results;
 
     return 1;
 }
